@@ -1,12 +1,9 @@
 /*
-  Copyright (c) 2000-2001 Nikolas Zimmermann <wildfox@kde.org>
-            (c) 2000-2001 Daniel Molkentin <molkentin@kde.org>
-            (c) 2007 Paolo Capriotti <p.capriotti@gmail.com>
-            
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
+    SPDX-FileCopyrightText: 2000-2001 Nikolas Zimmermann <wildfox@kde.org>
+    SPDX-FileCopyrightText: 2000-2001 Daniel Molkentin <molkentin@kde.org>
+    SPDX-FileCopyrightText: 2007 Paolo Capriotti <p.capriotti@gmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "stats.h"
@@ -60,6 +57,4 @@ void Stats::addInfo(const HitInfo& info)
     }
 }
 
-
-
-
+#include "moc_stats.cpp"
